Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func JWT ¶
JWT deal with the token passed in if token is nil,or can't pass the check,or timeout,it will return error query expire time in redis TODO: refresh jwt expire time in redis
func MiddlewareLogging ¶
func MiddlewareLogging(log *logrus.Logger) gin.HandlerFunc
func RequestRateLimiter ¶
func RequestRateLimiter(maxRequests int64, period time.Duration) gin.HandlerFunc
Example: RequestRateLimiter(3, time.Minute) represents 3 requests per minute
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.